UsersApi class

Constructors

UsersApi(BackendHttp _http)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateAccount(Map<String, dynamic> payload) Future
getById(String id) Future<Map<String, dynamic>?>
getByUsername(String username) Future<Map<String, dynamic>?>
me() Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Map<String, dynamic> payload) Future
resetPassword(Map<String, dynamic> payload) Future
sendActivationCode(Map<String, dynamic> payload) Future
sendCode(Map<String, dynamic> payload) Future
sendResetCode(Map<String, dynamic> payload) Future
toString() String
A string representation of this object.
inherited
updateMe(Map<String, dynamic> payload) Future<Map<String, dynamic>?>

Operators

operator ==(Object other) bool
The equality operator.
inherited